function evap = CALC_EvapdH(evap)
global c

for n = 1:length(c.Mi)
    %% Integrate through unit cell, co-current, used as guess for counter-current
    Y = ODE(evap,n);
    evap.guess = Y;
    
    %% Integrate thru counter-current RED cell
    Y = BVP(evap,n)';
    evap.m_cavr(n,1) = sum(Y(:,1))./length(Y(:,1));
    evap.m_davr(n,1) = sum(Y(:,2))./length(Y(:,2));
    evap.m_cout(n,1) = Y(end,1);
    evap.m_dout(n,1) = Y(1,2);
    evap.Fwcout(n,1) = Y(end,3);
    evap.Fwdout(n,1) = Y(1,4);
    Y = pchip(linspace(0,c.Lchannel,length(Y(:,1))),Y',linspace(0,c.Lchannel,10))';
    p.E_unit = -CALC_Eunit(evap.m_cavr(n), evap.m_davr(n), c.T);  
    p.R_unit = CALC_Runit(evap.m_cavr(n), evap.m_davr(n), c.T);
    [~, evap.N_unit(n), ~] = CALC_FH2(p.E_unit(n), p.R_unit(n));
    
    %% Find side flows F1 and F2
    fun = @(X)FEVAP(X,evap,n);
    %     Fw1, Fw2
    X0 = [0,0];
    ub = (ones(1,2).*c.Fw.*evap.N_unit(n)*c.scaleF);
    options = optimoptions('lsqnonlin','MaxFunctionEvaluations',1e6,'MaxIterations',1e6);
    X(n,:) = lsqnonlin(fun,X0,[-ub(1),0],ub,options);
    X(n,1:2)=X(n,1:2)./c.scaleF;
    evap.Fw2 = X(:,2);
    evap.Fw1 = X(:,1);
    
    %% Calculate total mass flow at every point in RED cell and for all flows in regen system
    evap.FtotREDc(n,:) = Y(:,3)'.*evap.N_unit(n).*(1+Y(:,1)'.*c.Mi(n)); % Total mass flow conc channels RED
    evap.FtotREDd(n,:) = Y(:,4)'.*evap.N_unit(n).*(1+Y(:,2)'.*c.Mi(n)); % Total mass flow dilute channels RED
    evap.Ftot(n,1) = evap.Fwdout(n).*evap.N_unit(n).*(1+evap.m_dout(n).*c.Mi(n)); % Total mass flow out of dilute
    evap.Ftot(n,2) = evap.Fw1(n).*(1+evap.m_dout(n).*c.Mi(n)); % Side flow from dilute to conc
    evap.Ftot(n,3) = evap.Ftot(n,1)-evap.Ftot(n,2); % Total mass flow spent dilute minus side flow
    evap.Ftot(n,4) = evap.Fwcout(n).*evap.N_unit(n).*(1+evap.m_cout(n).*c.Mi(n)); % Total mass flow out of conc
    evap.Ftot(n,5) = evap.Ftot(n,4)+evap.Ftot(n,2); % Into boiler
    evap.Ftot(n,6) = evap.Fw2(n); % Evaporate
    evap.Ftot(n,7) = evap.Ftot(n,5)-evap.Ftot(n,6); % Refreshed Conc
    evap.Ftot(n,8) = evap.Ftot(n,6)+evap.Ftot(n,3); % Refreshed Dilute
    
    %% Calculate energy flow at every point in RED cell and for all flows in regen system
for i = 1:length(evap.FtotREDc(1,:))
    temp = CALC_CpSol(Y(i,1),c.T); temp2 = CALC_CpSol(Y(i,2),c.T); 
    evap.CpREDc(n,i)=temp(n); evap.CpREDd(n,i) = temp2(n); % Heat capacity
end
    evap.Qc(n,:) = evap.FtotREDc(n,:).*evap.CpREDc(n,:).*c.T;
    evap.Qd(n,:) = evap.FtotREDd(n,:).*evap.CpREDd(n,:).*c.T;
    evap.Qtot(n,:) = evap.Qc(n,:) + fliplr(evap.Qd(n,:));  
    evap.QtotDiff(n,:) = evap.Qtot(n,1) - evap.Qtot(n,end);
    evap.Qcdiff(n,:) = evap.Qc(n,1) - evap.Qc(n,:);
    evap.Qddiff(n,:) = evap.Qd(n,end) - evap.Qd(n,:);
%     evap.Tc(n,:) = (evap.Qc(n,1)-evap.Qc(n,end))./(evap.FtotREDc(n,end).*evap.CpREDc(n,end));
%     evap.Td(n,:) = (evap.Qd(n,end)-evap.Qd(n,1))./(evap.FtotREDd(n,1).*evap.CpREDd(n,1));
    
    evap.Q(n,1) = evap.Qd(n,1);
    temp = CALC_CpSol(Y(1,2),c.T); 
    evap.Q(n,2) = evap.Ftot(n,2).*temp(n).*c.T;
    evap.Q(n,3) = evap.Q(n,1)-evap.Q(n,2);
    evap.Q(n,4) = evap.Qc(n,end);
    evap.Q(n,5) = evap.Q(n,4)+evap.Q(n,2);
    temp = CALC_CpSol(0,c.T); 
    evap.Q(n,6) = evap.Ftot(n,6).*temp(n).*c.T + evap.Ftot(n,6).*c.Hevap.*3600;
    evap.Q(n,7) = evap.Ftot(n,6).*temp(n).*c.T;
    evap.Q(n,8) = evap.Q(n,5)-evap.Q(n,7); % Refreshed CONC
    evap.Q(n,9) = evap.Q(n,3)+evap.Q(n,7); % Refreshed DILUTE
    
    evap.Qrefresh(n,1) = evap.Q(n,9)-evap.Qd(n,end)+(evap.Q(n,8)-evap.Qc(n,1)); % Diff between refreshed and RED inlet
    
% nflow(n) = evap.m_cout(n).*evap.Fwcout(n)+evap.m_dout(n).*evap.Fw1(n);
% m5(n) = nflow(n)./(evap.Fw1(n)+evap.Fwcout(n));
% Cp=CALC_CpSol(evap.m_cout(n),c.T); Ttest(n) = evap.Q(n,5)./(evap.Ftot(n,5).*Cp(n));

% dx = diff(evap.FtotREDc(1,:));
% Qc(1) = evap.Qc(1,1);
% for i =2:length(evap.FtotREDc(1,:))
% Qc(i)=Qc(1)+dx(i-1)*evap.CpREDd(1,i)
% end

end
evap = CALC_Molarity(evap);
[evap.Js, evap.Jw] = CALC_Fluxes(evap); 


%% Pump work and work needed for evaporation regen
evap.dp = (1013.3-73.48)*1e+2; % Pa, delta pressure to make water boiling point 40C
evap.P_pump1 = (evap.Fw2)./(CALC_Density(0)).*1e-3.*evap.dp./0.6;
evap.P_pump2 = (evap.N_unit.*c.Fw + evap.N_unit.*c.Fw.*evap.m_c.*c.Mi)./(CALC_Density(evap.m_c)).*1e-3.*evap.dp./0.6;
evap.dH = c.Cpw.*60.*3600.*(evap.N_unit.*evap.Fwcout+evap.Fw1); % Heating to 100 instead of vacuum
evap.H  = evap.Fw2.*c.Hevap.*3600 + evap.P_pump1 + evap.P_pump2; % W, evap.dH; 



end