function dYdZ = DIFF(Z,Y,n)
global c
n_c  = Y(1,1)/c.scaleF; % mol/s
n_d  = Y(2,1)/c.scaleF; % mol/s
n_wc = Y(3,1)/c.scaleF; % mol/s
n_wd = Y(4,1)/c.scaleF; % mol/s
T_c  = Y(5,1); % K
T_d  = Y(6,1); % K 

F_wc = n_wc.*c.Mw; % kg/s
F_wd = n_wd.*c.Mw; % kg/s
F_totc = F_wc + n_c.*c.Mi(n); % kg/s
F_totd = F_wd + n_d.*c.Mi(n); % kg/s
m_c = n_c./F_wc; % mol/kg
m_d = n_d./F_wd; % mol/kg

E_unit = CALC_Eunit(m_c, m_d, (T_c+T_d)/2);  
R_unit = CALC_Runit(m_c, m_d, (T_c+T_d)/2);
[j_max, ~, ~] = CALC_FH2(E_unit, R_unit, (T_c+T_d)/2, m_c, m_d);

[c_c, c_d, c_wc, c_wd] = CALC_Molarity(m_c, m_d);
[Js, Jw] = CALC_Fluxes(j_max, c_c, c_d, c_wc, c_wd); % mol/m2/s Net flux into one high conc compartment
Jq = 2.*c.U.*(T_c - T_d); % W/m2

[hsc, hwc] = CALC_Hbar(m_c, T_c); % J/mol
[hsd, hwd] = CALC_Hbar(m_d, T_d);

xsc = n_c./(n_c+n_wc); 
xsd = n_d./(n_d+n_wd);

Cpc = CALC_Cp(m_c, T_c)./(xsc.*c.Mi(n)+(1-xsc).*c.Mw); % J/K kg
Cpd = CALC_Cp(m_d, T_d)./(xsd.*c.Mi(n)+(1-xsd).*c.Mw); % J/K kg

DncDy = c.Wchannel.*Js(n);
DndDy = -c.Wchannel.*Js(n);
Dn_wc = c.Wchannel.*Jw(n);
Dn_wd = -c.Wchannel.*Jw(n);
DT_c = c.Wchannel.*(-1.*Jq - max(0,Jw(n)).*(hwc(n)-hwd(n)))./(F_totc.*Cpc(n));
DT_d = c.Wchannel.*( 1.*Jq + max(0,-Jw(n)).*(hwc(n)-hwd(n)) - Js(n).*(hsc(n)-hsd(n)))./(F_totd.*Cpd(n)); % 

%% 
dYdZ = [DncDy.*c.scaleF
        DndDy.*c.scaleF
        Dn_wc.*c.scaleF
        Dn_wd.*c.scaleF
        DT_c
        DT_d];



end