global c

c.T = 273.15+40;
c.Tl = 273.15+10;
c.scaleF = 1; % 1e5;
c.H2conv = 89.88; % g/m3

%% STACK
c.Fw = (2.7e-04); % kg/s WATER FLOW IN EACH CHANNEL PER UNIT CELL > 1 cm/s

c.Pevap = 0.072045398; % atm
c.HHV = 141.88*1e6; % J/kg
c.LHV = 120.0*1e6;

c.d = (270e-6); % 155e-6; % Spacer width
c.IEMbeta = 1.56; % % Shadow factor
c.IEMeps = 0.84; % Porosity
c.Lchannel = 10e-2; % Channel length m
c.Wchannel = 10e-2; % Channel width m
c.Am = c.Lchannel*c.Wchannel; % Membrane active area 100cm2   
c.dm    = 125e-6;
c.dmold = 125e-6;
c.R_CEM = (2.96e-4)./c.dmold*c.dm; % Tamburini
c.R_AEM = (1.55e-4)./c.dmold*c.dm; % ohm m2

c.vv = c.Fw/(c.Wchannel*c.d*1e2)*10; % kg/(s dm2)/(1kg/dm3)*10 = cm/s

c.De = 1e-12; % 5e-11 
c.Dw = 1e-11; % 
c.U = 1000; %W/m2/K

c.tM = 0.975;
c.tX = 0.025;
c.t_e = 0.5*(c.tM - c.tX); % CEM, for AEM t_e is -c.t_e
c.t_w = 3; %0;

%% Electrochemical
c.F = 96485; % [C/mol]
c.R = 8.314; % [J/Kmol]
c.epsilon0 = 8.854e-12;
c.Na = 6.02214e+23;
c.e = 1.602e-19;
c.kB = 1.3806e-23;
c.c = 3e6;

        c.prodH2 = 1;
if c.prodH2 == 1
    c.E_h = 1.23; % V
    c.E_L = 0.2;  % V +0.57
else
    c.N = 9; % Unit cells (always c.N+1)
    c.E_h = 0; % V
    c.E_L = 0;  % V
end
        
        
%% Electrolyte
c.m_slurry = 20; % mol/kg slurry molality
c.S40 = [%9.16    % NH4Br
%         8.58    % NH4Cl
%         4.89    % NH4HCO3
%         24.25   % LiBr
%         21.17   % LiCl
%         21.85   % LiNO3
%         6.39    % KBr
        5.37    % KCl
%         24.55   % KF
%         6.22    % KNO3
%         10.36   % NaBr
%         10.85
];   % NaCl
        
c.S10 = [%6.86
%         6.27
%         2.01
%         17.34
%         17.41
%         8.74
%         5.00
        4.15
%         11.38
%         2.11  
%         8.25
%         8.22
        ];

c.MH2 = 2*1.008*1e-3; % [kg/mol] 
c.Mw = 18.02*1e-3;
c.Mi = [%97.943  % NH4Br
%         53.492  % NH4Cl
%         79.056  % NH4HCO3
%         86.845  % LiBr
%         42.394  % LiCl
%         68.946  % LiNO3
%         119.002 % KBr
        74.551  % KCl
%         58.0967 % KF
%         101.103 % KNO3
%         102.894 % NaBr
%         58.443
        ].*1e-3;  % NaCl [kg/mol] 

    
c.Hevap = 2257200; %J/kg

%% Heat Capacity, from CRISS et al., not f(T) yet
c.Cpw0  = 1.16*3600*c.Mw; % J/K/mol
c.Cpwg  = 33.6524; % J/K/mol
c.Cp0 = [%-59.35
%          -54.40
%          -54.40 % ASSUMED = NH4CL (lacking data)
%          -68.15
%          -63.2 
%          -63.2  % ASSUMED = LiCL (lacking data)
%          -118.81
         -113.86
%          -128.33 %-105.28 KF assumed = KOH (lacking data)
%          -61.04
%          -88.26
%          -88.31
]; % J/Kmol

c.bJ = [% -5.97e-6, 0,        0;          % NH4Br
%          -5.97e-6, 4.44e-6,  2.89e-7;    % NH4Cl
%          -5.97e-6, 4.44e-6,  2.89e-7;       % NH4HCO3
%          -2.92e-6, 1.17e-5,  2.32e-7;    % LiBr
%          -3.10e-6, 1.36e-5,  6.28e-8;    % LiCl
%          -3.10e-6, 1.36e-5,  6.28e-8;       % LiNO3
%          -1.43e-5, 7.62e-6,  1.08e-6;    % KBr
         -1.24e-5, 2.92e-6,  9.17e-7;    % KCl
%          -9.46e-6, -2.59e-5, 3.19e-7;   % KF assumed = KOH due to data only going to 1M
%          -7.85e-6, -8.26e-5, 0      ;   % KNO3
%          -1.30e-5, -1.06e-5, 5.8e-7;    % NaBr
%          -1.53e-5, -3.65e-7, 9.12e-7
];  % NaCl           

%% Mixing enthalpy
c.H0fw = -285.8*1e3; % J/mol 
c.H0f = [%-271.54
%          -314.55
%          -853.39
%          -350.91
%          -408.27
%          -482.3
%          -393.80
         -436.68
%          -568.61
%          -494.00
%          -361.41
%          -411.12
         ].*1e3; % std enthaly of formation (25C, 1atm) % Chase et al. Thermochemical Tables 
     
c.H0mix = [% 16.78 % NH4Br, J/mol, infinite dilution
%             14.78   % NH4Cl
%             26.09   % NH4HCO3
%             -48.83  % LiBr
%             -37.03  % LiCl
%             -2.51   % LiNO3
%             19.87   % KBr
            17.22   % KCl
%             -17.73  % KF
%             34.89   % KNO3
%             -0.6    % NaBr
%             3.88
            ].*1e3;    % NaCl

c.bL = [% 0.77e-4, 1.25e-3,   2.1e-5;       % NH4Br assumed = NH4Cl (lacking data)
%          0.77e-4, 1.25e-3,   2.1e-5;    % NH4Cl
%          0.77e-4, 1.25e-3,   2.1e-5;       % NH4HCO3 assumed = NH4Cl (lacking data)
%          -1.81e-4, 6.63e-4,  2.81e-5;   % LiBr
%          -1.68e-4, 5.36e-4,  4.52e-5;   % LiCl
%          -1.81e-4, 6.63e-4,  2.81e-5;       % LiNO3 assumed = LiBr
%          7.39e-4, 1.74e-3,  -7.00e-5;   % KBr
         5.79e-4, 1.071e-3, -5.09e-5;   % KCl
%          2.14e-4, 5.44e-4,  -5.9e-5;    % KF
%          2.06e-4, 6.45e-3,   3.97e-4;   % KNO3
%          7.69e-4, 1.07e-3,  -9.30e-5;   % NaBr
%          7.15e-4, 7.00e-4,  -1.05e-4
];  % NaCl                 
        
%% Standard Entropy 
c.S0fw = 69.9; % J/Kmol liquid
c.S0f = [%82.56	
%          82.56	
%          82.56	
%          82.56	
%          82.56	
%          82.56	
         82.56 % KCl	Only KCl is used atm, need to find for other species
%          82.56	
%          82.56	
%          82.56	
%          82.56	
%          82.56
         ]; % J/K mol     
     
%% Density, not f(T) yet        
c.rhow = 0.99707; % kg/L
c.rhoi=[%0.0528
%         0.0119
%         0.03696
%         0.0370
%         0.0213
%         0.0279
%         0.0706
        0.0368
%         0.0485
%         0.0521
%         0.0782
%         0.0380
];
 
% msat25 = 4.76 mol/kg
% csat25 = 4.1184 mol/L
% C = [0.1	1	3	3.5	4	4.1184];
% f = @(m)[m.*(c.rhow+c.rhoi*m - C.*c.Mi) - C];
% m0 = C;
% m = fsolve(f,m0)

% mm = [m(1) m(2) m(3) m(3) m(4) m(4) m(5) m(6) m(6)]';
% X = [ones(length(mm),1) log(mm)];
% Y = [289.9  236.1  207.3  209.9  203.3  204.2  200.2  196.6  198.6]';
% B = (X'*X)\X'*Y;
% E = Y - X*B;
% MSE = (E'*E)/(length(Y)-length(B)); % Regression variance
% Covar = MSE*((X'*X)\eye(size(B,1))); % Covariance matrix  


%% Conductivity, not f(T) yet
% mimat = load('mi.mat');
% kimat = load('ki.mat');
% for i = 1:length(c.Mi)
%     mi = mimat.mi(i,all(~isnan(mimat.mi(i,:)),1));
%     ki = kimat.ki(i,all(~isnan(kimat.ki(i,:)),1));
%     modelfun = @(b,mi)(b(1).*mi.^b(2).*exp(-b(3).*mi)); % 3 parameter fit to experimental data
%     beta0 = [10,1,0.1]; opts = statset('nlinfit');
%     beta = nlinfit(mi,ki,modelfun,beta0,opts);
%     c.beta(i,:) = beta;
% end
% clear mimat kimat mi ki modelfun beta0 beta

c.beta = [%13.0285484721093,1.06022857898075,0.0826983671669377;
%             10.2113156943252,1.00603223408828,0.0378063175124477;
%             7.37244546863778,0.868036964695779,0.0882605852024419;
%             7.84652118538189,0.969776261553823,0.140924765864078;
%             8.72437208690178,1.33783089203108,0.310368275534493;
%             7.63945240008416,0.999709980942018,0.192970179566214;
%             16.7276068381919,1.65468112346652,0.382224632335289;
            9.944,0.9282 ,0.03952 ; % KCl
%             9.15007995759375,1.15569176714934,0.174113461366741;
%             8.71473787438218,0.884967262457322,0.0292977080721038;
%             10.7574557413098,1.14179222831816,0.224056110015812;
%             9.57977572661873,0.868003174981662,0.107915663405717
];

%% Activity coeff, not f(T)
c.b =  [%0.0624      0.1947      -0.00436;
%         0.0522      0.1918      -0.00301;
%         -0.038      0.07        0;
%         0.4159      -4.907      -0.011;
%         0.2176      -0.01       -0.005279;
%         0.1321      0.2233      -0.004439;
%         0.05251     0.1376      -0.001439;
        0.047     0.2124      -0.0005953;            %0.04386     0.1258      -0.0005138;
%         0.07617     0.1204      0.001348;
%         -0.08372	-0.02629	0.006673;
%         0.09492     0.1834      0.00105;
%         0.0727      0.0727      0.001474
];

    
    
    
    
    
    
%% test mixing
% nn = 100;
% for i=1:length(c.Mi)
%    c.mm(i,:)=linspace(1e-9,c.S40(i),nn);
%    c.wm(i,:)=c.mm(i,:).*c.Mi(i)./(1+c.mm(i,:).*c.Mi(i));
%    c.ntot(i,:)=(c.mm(i,:)+1./c.Mw);
%    c.xm(i,:)=c.mm(i,:)./c.ntot(i,:);
%    for j=1:nn
%     Hmix=CALC_Hmix(c.mm(i,j),c.T);
%     c.Hmix(i,j) = Hmix(i); 
%     c.Hmixn(i,j) = c.Hmix(i,j).*c.mm(i,j);
%     c.Hmixnn(i,j) = c.Hmix(i,j)./c.ntot(i,j);
%     
%     % 1kg water basis
%     c.H(i,j) = c.H0f(i)*c.mm(i,j)+c.H0fw/c.Mw + c.Hmixn(i,j); % J
%     c.Hm(i,j)= c.H(i,j)./c.ntot(i,j);
%    end
%    c.dHdx(i,:) = dss020(c.xm(i,1),c.xm(i,end),nn,c.Hm(i,:),1);
%    c.Hs(i,:)= c.Hm(i,:) + (1-c.xm(i,:)).*c.dHdx(i,:);
%    c.Hw(i,:)= c.Hm(i,:) - c.xm(i,:).*c.dHdx(i,:);
%    testHm(i,:) = (1-c.xm(i,:)).*c.Hw(i,:) + c.xm(i,:).*c.Hs(i,:);
% end

% for i=1:length(c.Mi)
%    c.mm(i,:)=linspace(0,c.S40(i),nn);
%    c.wm(i,:)=c.mm(i,:).*c.Mi(i)./(1+c.mm(i,:).*c.Mi(i));
%    for j=1:nn
%     cptemp=CALC_Cp(c.mm(i,j),c.T);
%     c.Cp(i,j) = cptemp(i); clear cptemp;
%    end
% end

%% graphs
% for i=1:12
% plot(c.mm(i,:),c.Hmix(i,:).*1e-3); hold on
% end
% xlabel('m  /  mol kg^{-1}'); ylabel('H_{mix}  /  kJ mol^{-1}')

% for i=1:12
% plot(c.xm(i,:),c.H(i,:).*1e-3); hold on
% end
% xlabel('m  /  mol kg^{-1}'); ylabel('H  /  kJ')
% xlabel('\omega  /  -'); ylabel('H  /  kJ')
% scatter(ones(12,1), c.H0f.*1e-3)
% scatter(0,c.H0fw.*1e-3)

% n = 4;
% plot(c.xm(n,:),c.Hm(n,:).*1e-3,'Linewidth',1.75); hold on;
% plot(c.xm(n,:),c.xm(n,:).*c.Hs(n,:).*1e-3,'Linewidth',1.75); 
% plot(c.xm(n,:),(1-c.xm(n,:)).*c.Hw(n,:).*1e-3,'Linewidth',1.75); 
% x = linspace(0,1,nn); y = (c.H0fw.*(1-x)+c.H0f(n).*x).*1e-3;
% plot(x,y,'--k','Linewidth',1.5);
% scatter(1, c.H0f(n).*1e-3, 100, 'k','s','filled')
% scatter(0, c.H0fw.*1e-3, 100, 'k','filled')
% xlabel('x_s  /  -'); ylabel('H/n  /  kJ/mol')
% set(gca,'FontName','Arial','FontSize',14,'linewidth',1);
% legend('H/n','x_sH_s','x_wH_w','x_s\DeltaH_{f,s}^0+x_w\DeltaH_{f,s}^0','\DeltaH_{f,s}^0','\DeltaH_{f,w}^0'); legend boxoff
%     

% test = (y-c.Hm(n,:).*1e-3)./c.xm(n,:);


% n = 5;
% plot(c.xm(n,:),c.Hmixnn(n,:).*1e-3,'Linewidth',1.75); hold on;
% plot(c.xm(n,:),c.xm(n,:).*c.Hs(n,:).*1e-3,'Linewidth',1.75); 
% plot(c.xm(n,:),(1-c.xm(n,:)).*c.Hw(n,:).*1e-3,'Linewidth',1.75); 
% x = linspace(0,1,nn); y = (c.H0fw.*(1-x)+c.H0f(n).*x).*1e-3;
% plot(x,y,'--k','Linewidth',1.5);
% scatter(1, c.H0f(n).*1e-3, 100, 'k','s','filled')
% scatter(0, c.H0fw.*1e-3, 100, 'k','filled')
% xlabel('x_s  /  -'); ylabel('H_{mix}  /  kJ'); xlim([0 1]); ylim([-1e1 0])
% set(gca,'FontName','Arial','FontSize',14,'linewidth',1);


%% Cycle
% m = 5; 
% t = 298.15:1:313.15;
% h25 = (c.H0f(12)*m+c.H0fw/c.Mw)*1e-3; % kJ
% hwater = 4184*(t(end)-t(1))*1e-3; % kJ
% hnacl = 50*(t(end)-t(1))*m*1e-3; % kJ
% h40 = c.H0f(12)*m*1e-3+hnacl+c.H0fw/c.Mw*1e-3+hwater; % kJ
% hm25 = h25 + CALC_Hmix(m,298.15)./1000.*m; % kJ
% hm40 = h40 + CALC_Hmix(m,273.15+40)./1000.*m; % kJ 
% for i = 1:length(t)
%     cp(:,i) = CALC_Cp(m,t(i));
% end
% cpavr = mean(cp,2);
% htmixed = cpavr.*(t(end)-t(1)).*(1/c.Mw + m)./1000; %kJ 
% htmixed2 = trapz(t,(1/c.Mw + m).*cp(12,:)./1000); %kJ 
% 
% hm25 + htmixed - CALC_Hmix(m,273.15+40)./1000.*m;
% 
% 
% clear Hmix modelfun opts mi ki kimat mimat i j beta beta0 testHM nn 

