function evap = evapRegen(p)
global c

%% Dependence of n1 and n2 on slurry concentration
% ns = 8;
% x=linspace(3,50,100);
% y1=(p.m_c(ns,end)*(p.n_c(ns,end)-p.n_c(ns,1)).*p.N_unit+p.m_c(ns,end).*x.*c.Mw.*(p.n_wc(ns,end)-p.n_wc(ns,1)).*p.N_unit)./(p.m_c(ns,end)-x);
% y2=(p.n_c(ns,end)-p.n_c(ns,1)).*p.N_unit - y1;
% plot(x,y1); hold on
% plot(x,-y2)

%% For counter-current flow
evap.Ns(:,1) = p.n_c(:,end).*p.N_unit; % Concentrate outlet salt flow
evap.Ns(:,2) = p.n_d(:,1).*p.N_unit;   % Dilute      outlet salt flow
% Stream n1, side flow from spent dilute to spent concentrate
evap.Ns(:,3) = (p.n_d(:,1)-p.n_d(:,end)).*p.N_unit;
% Stream n2, salt flow from slurry tank to spent concentrate
evap.Ns(:,4) = 0; 
evap.Ns(:,5) = evap.Ns(:,1) + evap.Ns(:,3); % Refreshed concentrate
evap.Ns(:,6) = evap.Ns(:,2) - evap.Ns(:,3); % Refreshed dilute
evap.Ns(:,7) = p.n_c(:,1).*p.N_unit;      % Concentrate inlet salt flow
evap.Ns(:,8) = p.n_d(:,end).*p.N_unit;    % Dilute      inlet salt flow

evap.Nw(:,1) = p.n_wc(:,end).*p.N_unit; % Concentrate outlet salt flow
evap.Nw(:,2) = p.n_wd(:,1).*p.N_unit;   % Dilute      outlet salt flow
% Stream n1, side flow to spent concentrate from spent dilute
evap.Nw(:,3) = evap.Ns(:,3)./p.m_d(:,1)./c.Mw;
% Stream n2, water flow from evaporator to spent dilute
evap.Nw(:,4) = evap.Nw(:,3) - (p.n_wd(:,1) - p.n_wd(:,end)).*p.N_unit;
evap.Nw(:,5) = evap.Nw(:,1) + evap.Nw(:,3) - evap.Nw(:,4); % Refreshed concentrate
evap.Nw(:,6) = evap.Nw(:,2) - evap.Nw(:,3) + evap.Nw(:,4); % Refreshed dilute
evap.Nw(:,7) = p.n_wc(:,1).*p.N_unit;     % Concentrate inlet salt flow
evap.Nw(:,8) = p.n_wd(:,end).*p.N_unit;   % Dilute      inlet salt flow

evap.Ftot(:,1) = evap.Ns(:,1).*c.Mi + evap.Nw(:,1).*c.Mw; % Total mass flow out of concentrate
evap.Ftot(:,2) = evap.Ns(:,2).*c.Mi + evap.Nw(:,2).*c.Mw; % Total mass flow out of dilute
evap.Ftot(:,3) = evap.Ns(:,3).*c.Mi + evap.Nw(:,3).*c.Mw; % Total mass flow side flow
evap.Ftot(:,4) = evap.Ns(:,4).*c.Mi + evap.Nw(:,4).*c.Mw; % Water evaporate flow out of evaporator
evap.Ftot(:,5) = evap.Ns(:,5).*c.Mi + evap.Nw(:,5).*c.Mw; % Total mass flow refreshed conc
evap.Ftot(:,6) = evap.Ns(:,6).*c.Mi + evap.Nw(:,6).*c.Mw; % Total mass flow refreshed dilute
evap.Ftot(:,7) = evap.Ns(:,7).*c.Mi + evap.Nw(:,7).*c.Mw; % Total mass flow INTO concentrate
evap.Ftot(:,8) = evap.Ns(:,8).*c.Mi + evap.Nw(:,8).*c.Mw; % Total mass flow INTO dilute

%% Energy
for i = 1:8
    evap.m(:,i) = evap.Ns(:,i)./(evap.Nw(:,i).*c.Mw);
    for n = 1:length(c.Mi)
    [temp1, temp2] = CALC_Hbar(evap.m(n,i), c.T);
    evap.hs(n,i) = temp1(n,1);
    evap.hw(n,i) = temp2(n,1);

    Hmix = CALC_Hmix(evap.m(n,i), c.T);   
    evap.xs(n,i) = evap.m(n,i)./(evap.m(n,i)+1/c.Mw); 
    evap.M(n,i) = (evap.xs(n,i).*c.Mi(n)+(1-evap.xs(n,i)).*c.Mw);
    Hmixn = Hmix(n,1).*evap.m(n,i);   % J 
    evap.H(n,i)  = (c.H0f(n)*evap.m(n,i) + c.H0fw/c.Mw + Hmixn)./(evap.m(n,i)+1/c.Mw)./evap.M(n,i); % J/kg
    
    temp1 = CALC_Cp(evap.m(n,i), c.T)./evap.M(n,i); % J/K kg mixture
    evap.Cp(n,i) = temp1(n,1);
    evap.FH(n,i) = evap.Ftot(n,i).*evap.H(n,i);
    end
end
Hvap = CALC_Hvap(evap.m(:,4), c.T);
evap.Q(:,1) = evap.Ftot(:,4).*Hvap; % W
evap.Q(:,2) = evap.Ftot(:,4).*3600*24/6000*8000; % W, For 6000 L/24h -> 8kW (www.pf10.it catalogue)

end





% temp1 = CALC_Cp(0, c.T)./c.Mw; % J/K kg mixture
% evap.Cpw = temp1(1,1);
% evap.m = [p.m_c(:,end), p.m_d(:,1), (evap.Ns(:,1)+evap.Ns(:,3))./(evap.Nw(:,1)+evap.Nw(:,3))./c.Mw, (evap.Ns(:,2)-evap.Ns(:,3))./(evap.Nw(:,2)-evap.Nw(:,3))./c.Mw, ...
%             evap.Ns(:,7)./evap.Nw(:,7)./c.Mw, evap.Ns(:,8)./evap.Nw(:,8)./c.Mw];
% for i = 1:6
%     for n = 1:length(c.Mi)
%     [temp1, temp2] = CALC_Hbar(evap.m(n,i), c.T);
%     evap.hs(n,i) = temp1(n,1);
%     evap.hw(n,i) = temp2(n,1);
% 
%     Hmix = CALC_Hmix(evap.m(n,i), c.T);   
%     evap.xs(n,i) = evap.m(n,i)./(evap.m(n,i)+1/c.Mw); 
%     evap.M(n,i) = (evap.xs(n,i).*c.Mi(n)+(1-evap.xs(n,i)).*c.Mw);
%     Hmixn = Hmix(n,1).*evap.m(n,i);   % J 
%     evap.H(n,i)  = (c.H0f(n)*evap.m(n,i) + c.H0fw/c.Mw + Hmixn)./(evap.m(n,i)+1/c.Mw)./evap.M(n,i); % J/kg
%     
%     temp1 = CALC_Cp(evap.m(n,i), c.T)./evap.M(n,i); % J/K kg mixture
%     evap.Cp(n,i) = temp1(n,1);
%     end
% end
% 
% for n = 1:length(c.Mi)
%     evap.FH(n,1) = (evap.Ftot(n,1)+evap.Ftot(n,3)).*evap.H(n,3) - evap.Ftot(n,1).*evap.H(n,1); % Sideflow added to conc
%     evap.FH(n,2) = (evap.Ftot(n,2)-evap.Ftot(n,3)).*evap.H(n,4) - evap.Ftot(n,2).*evap.H(n,4); % Sideflow removed from dilute
%     evap.FH(n,3) = evap.Ftot(n,5).*evap.H(n,5) - (evap.Ftot(n,1)+evap.Ftot(n,3)).*evap.H(n,3); % Conc when water removed
%     evap.FH(n,4) = evap.Ftot(n,4).*evap.Cpw - (evap.Ftot(n,1)+evap.Ftot(n,3)).*evap.H(n,3);    % Water removed during evaporation
%     evap.Q(n,1) = evap.Ftot(n,4).*Hvap;
%     evap.FH(n,5) = evap.Ftot(n,8).*evap.H(n,6) - evap.Ftot(n,2).*evap.H(n,4);
% end