clear all
clc
global c
Parameters; % Constants

%% Numerical Optimization PRECIPITATION
for l = 1:length(c.Mi)
    Solinit = c.S40(l);
    LB = c.S10(l);
    UB = c.S40(l);
    NumOptions = optimset('Algorithm','sqp','Diagnostics', 'off', ...
                  'MaxFunEvals',1E10,'MaxIter',1e3,'TolCon',1e-20,'TolFun',1e-6 ); % 'Display', 'iter',

    EXITFLAG = -1;
    while EXITFLAG<=0 % EXITFLAG <=0 means that fmincon has not converged
      [Y,~,EXITFLAG,~,~,~] = ...
        fmincon(@(X)FMINoptPrecip(X,l), Solinit, -1, -c.S10(l), [], [], LB, UB, @(X)ConstraintsPrecip(X,l), NumOptions);
      Solinit = Y;
    end
    Sol(l,:) = Y;
end
precip.m_c = Sol(:,1);
precip.m_d = c.S10;

% precip = CALC_PrecipdH(precip);
% precip.H./(precip.F_H2.*1e6.*c.Am.*3600./c.H2conv)

%% Numerical Optimization EVAPORATION
for l = 1:length(c.Mi)
    l
    Solinit = [c.S40(l)-1;
               0.1];
    LB = zeros(2,1)+1e-10;
    UB = [c.S40(l);
          c.S40(l)];
    NumOptions = optimset('Algorithm','sqp','Diagnostics', 'off', ...
                  'MaxFunEvals',1E10,'MaxIter',1e3,'TolCon',1e-10,'TolFun',1e-6 ); % 'Display', 'iter',

    EXITFLAG = -1;
    while EXITFLAG<=0 % EXITFLAG <=0 means that fmincon has not converged
      [Y,~,EXITFLAG,~,~,~] = ...
        fmincon(@(X)FMINopt(X,l), Solinit, [], [], [], [], LB, UB, @(X)Constraints(X,l), NumOptions);
      Solinit = Y;
    end
    SolEvap(l,:) = Y;
end
evap.m_c = SolEvap(:,1);
evap.m_d = SolEvap(:,2);

% evap   = CALC_EvapdH(evap);

%% CALC
precip = CALC_PrecipdH(precip);
evap   = CALC_EvapdH(evap);

%% GRAPHS
RESULTS = {'NH_4Br';'NH_4Cl';'NH_4HCO_3';'LiBr';'LiCl';'LiNO_3';'KBr';'KCl';'KF';'KNO_3';'NaBr';'NaCl'};
    k = 1;
for i=1:length(c.Mi)
    RESULTS(k,2) = {precip.F_H2(i).*1e3.*3600};
    RESULTS(k,3) = {precip.H(i)./(precip.F_H2(i).*1e6.*c.Am.*3600./c.H2conv)}; %kWh/m3
    RESULTS(k,4) = {precip.E_unit(i)};
    RESULTS(k,5) = {precip.m_c(i)};
    RESULTS(k,6) = {precip.m_d(i)};
    RESULTS(k,7) = {[c.R_CEM.*1e4 c.R_AEM.*1e4 precip.Rd(i).*1e4 precip.Rc(i).*1e4]};
    
    RESULTS(k,8)  = {evap.F_H2(i).*1e3.*3600};
    RESULTS(k,9)  = {evap.H(i)./(evap.F_H2(i).*1e6.*c.Am.*3600./c.H2conv)}; %kWh/m3
    RESULTS(k,10) = {evap.E_unit(i)};
    RESULTS(k,11) = {evap.m_c(i)};
    RESULTS(k,12) = {evap.m_d(i)};
    RESULTS(k,13) = {[c.R_CEM.*1e4 c.R_AEM.*1e4 evap.Rd(i).*1e4 evap.Rc(i).*1e4]};
    k=k+1;
end
clear k EXITFLAG i l LB UB NumOptions Solinit Sol SolEvap Y
SORTED = sortrows(RESULTS,2,'ascend');
X = categorical(SORTED(:,1));
X = reordercats(X,SORTED(:,1));

%% FIG 1
figure(1)
subplot(1,3,1); 
b1 = barh(X,[cell2mat(SORTED(:,2)),cell2mat(SORTED(:,8))],1,'LineWidth',0.5); box off; %'Facecolor',col
b1(1).FaceAlpha = 0.7;
b1(2).FaceAlpha = 0.7;
ax = gca; ax.XGrid = 'on'; ax.GridLineStyle = ':'; ax.GridAlpha = 0.5;
legend('Precipitation','Evaporation','Location','southeast'); legend boxoff
xlim([0 19]); xlabel('F_{H_2}  /  g m^{-2}h^{-1}')

subplot(1,3,2); 
b2 = barh(X,[cell2mat(SORTED(:,3)),cell2mat(SORTED(:,9))],1,'LineWidth',0.5); box off;
set(gca,'XScale','log')
% b2 = barh(X,[cell2mat(SORTED(:,3)).*89.88,cell2mat(SORTED(:,9)).*89.88],1,'LineWidth',0.5); % kWh/m2
b2(1).FaceAlpha = 0.7;
b2(2).FaceAlpha = 0.7;
b2(1).BaseValue = 0.0000001;
b2(2).BaseValue = 0.0000001;
ax = gca; ax.XGrid = 'on'; ax.GridLineStyle = ':'; ax.GridAlpha = 0.5; ax.MinorGridLineStyle='none';
% xlim([0 0.6]);
xticks([10 100 1000 10000 100000])
xticklabels({'10','100','1000','10000','100000'})
xlabel('Q_{H_2}  /  kWh m^{-3}')
xlim([50 30000]);


subplot(1,3,3); 
b3 = barh(X,[cell2mat(SORTED(:,4)),cell2mat(SORTED(:,10))],1,'LineWidth',0.5); box off
b3(1).FaceAlpha = 0.7;
b3(2).FaceAlpha = 0.7;
ax = gca; ax.XGrid = 'on'; ax.GridLineStyle = ':'; ax.GridAlpha = 0.5;
xlim([0 0.6]); xlabel('\Delta\phi_{unit}  /  V')


set(findall(gcf,'-property','FontSize'),'FontSize',12);
set(gcf, 'Position', 0.8*get(0, 'Screensize'));
% exportgraphics(gcf,'BarGraphs1.png','Resolution',300) 

%% FIG 2
figure(2)
subplot(3,1,1)
b4 = bar(X,[cell2mat(SORTED(:,5)),cell2mat(SORTED(:,6))],1,'LineWidth',0.5);
b4(1).FaceAlpha = 0.7;
b4(2).FaceAlpha = 0.7;
ax = gca; ax.YGrid = 'on'; ax.GridLineStyle = ':'; ax.GridAlpha = 0.5; ax.MinorGridLineStyle='none';
ylim([0 30]); ylabel('m_{precip}  /  mol kg^{-1}')
box off 
legend('m_c','m_d','location','eastoutside'); legend boxoff
xtickangle(30)

subplot(3,1,2)
b5 = bar(X,[cell2mat(SORTED(:,11)),cell2mat(SORTED(:,12))],1,'LineWidth',0.5);
b5(1).FaceAlpha = 0.7;
b5(2).FaceAlpha = 0.7;
b5(1).BaseValue = 0.0000001;
b5(2).BaseValue = 0.0000001;
ax = gca; ax.YGrid = 'on'; ax.GridLineStyle = ':'; ax.GridAlpha = 0.5; ax.MinorGridLineStyle='none';
ylim([0.01 50]); ylabel('m_{evap}  /  mol kg^{-1}')
set(gca, 'YScale', 'log')
yticks([0.1 1 10 100])
yticklabels({'0.1','1','10','100'})
box off;
legend('m_c','m_d','location','eastoutside'); legend boxoff
xtickangle(30)

% stackData(i, j, k) => (Group, Stack, StackElement)
tempp = cell2mat(SORTED(:,7));
tempp2= cell2mat(SORTED(:,13));
stackData(:,1,:) = tempp; stackData(:,2,:)=tempp2;
subplot(3,1,3)
b6 = plotBarStackGroups(stackData,X);
b6(1,1).FaceAlpha = 0.7; b6(1,2).FaceAlpha = 0.7; b6(1,3).FaceAlpha = 0.7; b6(1,4).FaceAlpha = 0.7;
b6(2,1).FaceAlpha = 0.7; b6(2,2).FaceAlpha = 0.7; b6(2,3).FaceAlpha = 0.7; b6(2,4).FaceAlpha = 0.7;
b6(1,1).FaceColor = [0.00,0.45,0.74]; b6(1,2).FaceColor = [0.85,0.33,0.10];
b6(2,1).FaceColor = [0.00,0.45,0.74]; b6(2,2).FaceColor = [0.85,0.33,0.10]; b6(2,4).FaceColor = [0.47,0.67,0.19];
box off; legend boxoff
ylim([0 15]); ylabel('R_{unit}  /  \Omega cm^{2}')
legend([b6(1,1),b6(1,2),b6(1,3),b6(1,4),b6(2,3),b6(2,4)],'CEM','AEM','c_{low} (precip)','c_{high} (precip)','c_{low} (evap)','c_{high} (evap)','location','eastoutside')
xtickangle(30)

set(findall(gcf,'-property','FontSize'),'FontSize',12);
set(gcf, 'Position', 0.8*get(0, 'Screensize'));
% exportgraphics(gcf,'BarGraphs2.png','Resolution',300) 
clear b1 b2 b3 b4 b5 b6 tempp tempp2

