global c
clear all
Parameters;
ks = 100; % Resolution
ns = 1; % Salt number
Z = linspace(0,c.Lchannel,ks); pIVP.Z = Z; pBVP.Z = Z;
% initial.m_c = 4.5*ones(length(c.Mi),1); 
% initial.m_d = 1*ones(length(c.Mi),1);
initial.m_c = c.S40(ns); 
initial.m_d = c.S10(ns);


%% COUNTER-CURRENT FLOW
for n = 1:length(c.Mi)
%     if n == 7
        Y = IVP(initial, n, pIVP.Z);       % Solve co-current flow initial value problem
        pIVP = IVPResults(Y, n, pIVP);    % Results from co-current flow
        initial.guess = Y;                 % Co-current flow used as initial guess for the boundary value problem    
        Y = BVP(initial, n, pIVP.Z)';      % Solve counter-current boundary value problem
        Y = pchip(Y(:,7), Y', Z)';        
        pBVP = BVPResults(Y, n, pBVP);    % Results from counter-current flow
%     else % Added to speed up for nonrelevant salts
%         Y = [c.Fw.*1.*ones(ks,1) c.Fw.*0.1.*ones(ks,1) c.Fw./c.Mw.*ones(ks,2) ones(ks,2).*c.T Z'];     
%         pBVP = BVPResults(Y, n, pBVP);    % Results from counter-current flow
%     end
end
clear n Y init
pBVP.precip = precipRegen(pBVP); %% Precipitation regeneration
pBVP.evap   = evapRegen(pBVP);   %% Evaporation regeneration

% RAPPORTERe P, etaHHV etaLHV


%%
FH2 = pBVP.H2.*3600*1e3; % g/m2/h
P   = pBVP.N_unit.*pBVP.j.*(pBVP.E - pBVP.R.*pBVP.j);
P1  = pBVP.N_unit.*pBVP.j_max.*(pBVP.E_unit - pBVP.R_unit.*pBVP.j_max);
QH2evap = (pBVP.evap.Q(ns,1)./1000)./(FH2.*c.Am);
QH2precipHeat = (pBVP.precip.Q(ns,2)+pBVP.precip.Q(ns,3)+pBVP.precip.Q(ns,5))./1000./FH2;
QH2precipCool = (pBVP.precip.Q(ns,1)+pBVP.precip.Q(ns,4))./1000./FH2;

etaevap = P.*c.Am./(pBVP.evap.Q(ns,1)+pBVP.evap.Q(ns,2)); % 0.01 m2
etaprecip = P.*c.Am./(pBVP.precip.Q(ns,2)+pBVP.precip.Q(ns,3)+pBVP.precip.Q(ns,5));
carnot = 1-(273.15+20)/(273.15+50);
eta2evap = etaevap/carnot;

MED = 40000.*pBVP.evap.Ftot(1,4)./1.*1e-3.*3600; % W
QH2evap2 = (MED./1000)./(FH2.*c.Am);


VD  = pBVP.evap.Q(1,1)./(pBVP.evap.Ftot(1,4)./1.*1e-3*3600)./1e3; % kWh/m3
% With 40 kWh/m3 -> 0.04 kWh/kg ->  0.2812 kW (Multi-effect distillation)
etaMED = P.*c.Am./MED;
eta2MED = etaMED./carnot;

HHV = pBVP.H2*c.Am*c.HHV; % kg/m2/s * m2 * J/kg
LHV = pBVP.H2*c.Am*c.LHV; % kg/m2/s * m2 * J/kg 
HHV/MED
LHV/MED

%% TEMPERATURE
plot(Z./Z(end),pBVP.T_c(ns,:),'--','Linewidth',2,'color',[185 87 0]./255); hold on
plot(Z./Z(end),pBVP.T_d(ns,:),'-','Linewidth',2,'color',[121 162 206]./255)
ylabel('$T$   /   K','Interpreter','latex')
xlabel('$z$ L$^{-1}$   /   $-$','Interpreter','latex')
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
set(gcf,'Position', [0 0 800 720]);
legend('Concentrate channel','Dilute channel')
legend boxoff

%% FLUXES
% plot(Z./Z(end),c.Wchannel.*pBVP.Js(ns,:),'-k','Linewidth',1.2); hold on
% plot(Z./Z(end),c.Wchannel.*pBVP.Jw(ns,:),'--k','Linewidth',1.2)

%% CONCENTRATION
% semilogy(Z./Z(end), pBVP.m_c(ns,:),'-','LineWidth',2); hold on;
% semilogy(Z./Z(end), pBVP.m_d(ns,:),'-','LineWidth',2); 
% legend('Concentrate channel','Dilute channel','location','east'); legend boxoff
% ylabel('$m_e$   /   mol kg$^{-1}$','Interpreter','latex')
% xlabel('$z$ L$^{-1}$   /   $-$','Interpreter','latex')
% ylim([0.009 2])
% yticklabels({'0.01','0.1','1'});
% set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
% set(gcf,'Position', [0 0 800 720]);

%% E and I profile
yyaxis left
plot(Z./Z(end),pBVP.E_unit(ns,:).*1000,'-','Linewidth',2,'color',[121 162 206]./255); hold on
ylabel('$E_{unit}$   /   mV','Interpreter','latex')
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
ylim([40 60])

yyaxis right
plot(Z./Z(end),pBVP.j_max(ns,:),'-','Linewidth',2,'color',[185 87 0]./255); hold on
ylabel('$j_{cell}$   /   A m$^{-2}$','Interpreter','latex')
xlabel('$z$ L$^{-1}$   /   $-$','Interpreter','latex')
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
set(gcf,'Position', [0 0 800 720]);
ylim([8 15])
ax1 = gca;
ax1.YColor = [185 87 0]./255;

%% SAVE
% cd C:\PhD\HeatToH2\Figures\ModelPaper\Graphs
% exportgraphics(gcf,'E_I_Profile.png','Resolution',600)
% cd C:\MATLAB\Heat2H2





%%
% subplot(1,2,1)
% plot(Z./Z(end), precip.m_c(ns,:),'k-','LineWidth',1.2); hold on;
% plot(Z./Z(end), precip.m_d(ns,:),'k--','LineWidth',1.2); 
% legend('Concentrate channel','Dilute channel','location','east'); legend boxoff
% set(gca,'FontSize',14,'linewidth',1.2);
% xlabel('Z L^{-1}  /  -'); ylabel('m  /  mol kg^{-1}')
% 
% subplot(1,2,2)
% plot(Z./Z(end), precip.F_wc(ns,:).*1e3,'k-','LineWidth',1.2); hold on; 
% plot(Z./Z(end), precip.F_wd(ns,:).*1e3,'k--','LineWidth',1.2); 
% legend('Concentrate channel','Dilute channel','location','northwest'); legend boxoff
% set(gca,'FontSize',14,'linewidth',1.2);
% xlabel('Z L^{-1}  /  -'); ylabel('F_w  /  g s^{-1}')
% 
% set(gcf, 'Position', [0 50 1.1*1080 0.6*720])
% exportgraphics(gcf,'CellProfiles.png','Resolution',600)


