global c
clear all
Parameters;
ks = 100; % Resolution
ns = 1; % Salt number
Z = linspace(0,c.Lchannel,ks); pIVP.Z = Z; pBVP.Z = Z;
initial.m_c = 4.5*ones(length(c.Mi),1); 
initial.m_d = 1*ones(length(c.Mi),1);
% precip.m_c = c.S40(7); 
% precip.m_d = c.S10(7);

kss = 20;
tw = linspace(0,10,kss);
Fw = linspace(log10((2.7e-04)./5),log10((2.7e-04)*10),kss);
Dw = linspace(log10(1e-10),log10(1e-13),kss);
Ds = linspace(log10(1e-10),log10(1e-13),kss);

Dw = 10.^Dw;
Ds = 10.^Ds;
Fw = 10.^Fw;

%% COUNTER-CURRENT FLOW
for i=1:kss
nnn = 1;
% c.t_w = tw(i);
% c.Fw = Fw(i);  
c.De = Ds(i); 
% c.Dw = Dw(i); nnn = 2;

for n = 1:length(c.Mi)
%     if n == 7
        Y = IVP(initial, n, pIVP.Z);       % Solve co-current flow initial value problem
        pIVP = IVPResults(Y, n, pIVP);     % Results from co-current flow
        initial.guess = Y;                 % Co-current flow used as initial guess for the boundary value problem    
        Y = BVP(initial, n, pIVP.Z)';      % Solve counter-current boundary value problem
        Y = pchip(Y(:,7), Y', Z)';        
        pBVP = BVPResults(Y, n, pBVP);    % Results from counter-current flow
%     else % Added to speed up for nonrelevant salts
%         Y = [c.Fw.*1.*ones(ks,1) c.Fw.*0.1.*ones(ks,1) c.Fw./c.Mw.*ones(ks,2) ones(ks,2).*c.T Z'];     
%         pBVP = BVPResults(Y, n, pBVP);    % Results from counter-current flow
%     end
end
clear n Y init
pBVP.precip = precipRegen(pBVP); %% Precipitation regeneration
pBVP.evap   = evapRegen(pBVP); %% Evaporation regeneration

FH2(i) = pBVP.H2(ns,1)*1000*3600; % g/m2/h
P(i)    = pBVP.N_unit(ns,1).*pBVP.j(ns,1).*(pBVP.E(ns,1) - pBVP.R(ns,1).*pBVP.j(ns,1));
MED(nnn,i) = 40000.*pBVP.evap.Ftot(1,4)./1.*1e-3.*3600; % W
eta1(i) = P(i).*c.Am./MED(nnn,i);

Nu(i) = pBVP.N_unit(ns,1);
Eu(i) = pBVP.E(ns,1);
Eunit(i,:) = pBVP.E_unit(ns,:);
Jw(i) = trapz(pBVP.Z,pBVP.Jw(ns,:));
FH2Q(i) =  (pBVP.evap.Q(ns,1)./1000)./FH2(i); % kWh/g/m2
mc(i,:) = pBVP.m_c(ns,:);
Tc(i,:) = pBVP.T_c(ns,:);
md(i,:) = pBVP.m_d(ns,:);
Td(i,:) = pBVP.T_d(ns,:);
JwDiff(i,:) = pBVP.JwDiff(ns,:);
JwEl(i,:) = pBVP.JwEl(ns,:);
JsDiff(i,:) = pBVP.JsDiff(ns,:);
JsEl(i,:) = pBVP.JsEl(ns,:);
% semilogy(Z./Z(end), pBVP.m_d(ns,:),'-','LineWidth',2); 

i

end

%% 2 Y-axis
tw2 = linspace(0,10,100);
Ds2 = linspace(1e-10,1e-13,100);
Dw2 = linspace(1e-10,1e-13,100);
Fw2 = (linspace(Fw(1),Fw(end),100)+linspace(Fw(1),Fw(end),100)*4.5*c.Mi)/(c.Wchannel*c.d*1e2)*10;
FH2v2 = interp1(tw,FH2,tw2);
Euv2 = interp1(tw,Eu,tw2);
Jwv2  = interp1(tw,Jw,tw2);
% Jsv2  = interp1(Ds,Js,Ds2);
DsMED  = interp1(Ds,MED(1,:),Ds2);
% DwMED  = interp1(Dw,MED(2,:),Dw2);
FH2Qv2 =  interp1(tw,FH2Q,tw2);
FH2QD2 =  interp1(Ds,FH2Q,Ds2);
FH2D2 = interp1(Ds,FH2,Ds2);


%% Diffusion Coeffs vs regen heat
loglog(Ds,MED(1,:),'--','LineWidth',3,'color',[185 87 0]./255); hold on
loglog(Ds,MED(2,:),'-','LineWidth',3,'color',[121 162 206]./255);
xlabel('$D_i$   /   m$^2$ s$^{-1}$','Interpreter','latex')
ylabel('$Q_{heating}$   /   W','Interpreter','latex')
yticks([1 10 100])
yticklabels({'1','10','100'});
legend('D_e','D_w','location','west'); legend boxoff
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
set(gcf,'Position', [0 0 800 720]);
ylim([1 200])


%% Number of unit cells, tw
yyaxis left
plot(tw,Nu,'-','LineWidth',3,'color',[121 162 206]./255); hold on
ylabel('$N_{unit}$   /   -','Interpreter','latex')
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
% ax1 = gca;
% ax1.YColor = [121 162 206]./255;

yyaxis right
plot(tw,Eu.*1e3,'--','LineWidth',3,'color',[185 87 0]./255); hold on
ax1 = gca;
ax1.YColor = [185 87 0]./255;
ylabel('$E_{unit}$   /   mV','Interpreter','latex')
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
xlabel('$t_w$   /   -','Interpreter','latex')

% legend('D_e','D_w','location','west'); legend boxoff

set(gcf,'Position', [0 0 800 720]);
% ylim([1 200])

%% 
% figure(1)
% yyaxis left
% plot(tw2,FH2v2,'-','LineWidth',2,'color',[121 162 206]./255); hold on
% % semilogx(Fw./(c.Wchannel*c.d*1e2).*10,FH2,'-','LineWidth',2,'color',[121 162 206]./255); hold on
% ylabel('$F_{H_2}$   /   g m$^{-2}$h$^{-1}$','Interpreter','latex')
% ax1 = gca;
% ax1.YColor = [121 162 206]./255;
% yyaxis right
% plot(tw2,FH2Qv2,'--','LineWidth',2,'color',[185 87 0]./255); hold on
% % semilogx(Fw./(c.Wchannel*c.d*1e2).*10,FH2Q,'--','LineWidth',2,'color',[185 87 0]./255); hold on
% ylabel('$Q_{H_2}$   /   kWh m$^{-2}$g$^{-1}_{H_2}$','Interpreter','latex')
% % xlabel('$v_{channel}$   /   cm s$^{-1}$','Interpreter','latex')
% xlabel('$t_w$   /   $-$','Interpreter','latex')
% set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
% set(gcf,'Position', [0 0 800 720]);
% % xticklabels({'0.1','1','10'});
% ax1 = gca;
% ax1.YColor = [185 87 0]./255;

%% 2 x-axis
% figure(2)
% % x1 = tw2;
% % x1 = Fw2;
% x1 = Ds2;
% y1 = FH2Qv2;
% x2 = Jwv2;
% y2 = FH2Qv2;
% t = tiledlayout(1,1);
% ax1 = axes(t);
% plot(ax1,x1,y1,'-k','LineWidth',2)
% % xlabel('$v_{channel}$   /   cm s$^{-1}$','Interpreter','latex')
% xlabel('$t_w$   /   $-$','Interpreter','latex')
% set(ax1,'FontName','Arial','FontSize',18,'linewidth',1.2);
% ax1.XColor = 'k';
% ax1.YColor = 'k';
% ax2 = axes(t);
% plot(ax2,x2,y1,':w','LineWidth',0.0001)
% xlim([x2(end),x2(1)])
% set(gca, 'xdir', 'reverse')
% ax2.XAxisLocation = 'top';
% ax2.YAxisLocation = 'left';
% ax2.Color = 'none';
% ax1.Box = 'off';
% ax2.Box = 'off';
% 
% ylabel('$Q_{H_2}$   /   kWh m$^{-2}$g$^{-1}_{H_2}$','Interpreter','latex')
% xlabel('$J_w$   /   mol m$^{-2}$s$^{-1}$','Interpreter','latex')
% set(ax1,'FontName','Arial','FontSize',18,'linewidth',1.2);
% set(ax2,'FontName','Arial','FontSize',18,'linewidth',1.2);
% set(gcf,'Position', [0 0 800 720]);

%% Diff vs el
% d1 = (mean(JwEl,2)+mean(JwDiff,2))';
% d2 = mean(JwDiff,2)';
% d3 = mean(JwEl,2)';
% figure(3)
% h1 = plot(tw,d1,'-k','LineWidth',2,'DisplayName','Total water flux'); hold on
% h2 = plot(tw,d2,'LineWidth',2,'color',[185 87 0]./255,'DisplayName','Diffusion water flux'); hold on
% h3 = plot(tw,d3,'LineWidth',2,'color',[121 162 206]./255,'DisplayName','Electroosmotic water flux'); hold on
% ylabel('$J_{w}$   /   mol m$^{-2}$s$^{-1}$','Interpreter','latex')
% xlabel('$t_w$   /   $-$','Interpreter','latex')
% set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
% set(gcf,'Position', [0 0 800 720]);
% legend([h1 h2 h3],'location', 'west')
% legend boxoff

d1 = (mean(JsEl,2)+mean(JsDiff,2))';
d2 = mean(JsDiff,2)';
d3 = mean(JsEl,2)';
figure(3)
h1 = semilogx(Ds,d1,'-k','LineWidth',2,'DisplayName','Total salt flux'); hold on
h2 = semilogx(Ds,d2,'LineWidth',2,'color',[185 87 0]./255,'DisplayName','Diffusion salt flux'); hold on
h3 = semilogx(Ds,d3,'LineWidth',2,'color',[121 162 206]./255,'DisplayName','Electroosmotic salt flux'); hold on
ylabel('$J_{s}$   /   mol m$^{-2}$s$^{-1}$','Interpreter','latex')
xlabel('$D_e$   /   $-$','Interpreter','latex')
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
set(gcf,'Position', [0 0 800 720]);
legend([h1 h2 h3],'location', 'west')
legend boxoff

%% CONCENTRATION
figure(3)
plot(Z./Z(end), Td(1,:),'-','LineWidth',3,'color',[121 162 206]./255); hold on;
plot(Z./Z(end), Tc(1,:),'--','LineWidth',3,'color',[185 87 0]./255); 
plot(Z./Z(end), Td(3,:),'-','LineWidth',3,'color',[121 162 206]./255); 
plot(Z./Z(end), Tc(3,:),'--','LineWidth',3,'color',[185 87 0]./255); hold on;
plot(Z./Z(end), Td(8,:),'-','LineWidth',3,'color',[121 162 206]./255); 
plot(Z./Z(end), Tc(8,:),'--','LineWidth',3,'color',[185 87 0]./255); hold on;
% semilogy(Z./Z(end), Tc(10,:),'-','LineWidth',2,'color',[185 87 0]./255); hold on;
% semilogy(Z./Z(end), Td(10,:),'-','LineWidth',2,'color',[121 162 206]./255); 
% semilogy(Z./Z(end), Tc(20,:),'-','LineWidth',2,'color',[185 87 0]./255); hold on;
% semilogy(Z./Z(end), Td(20,:),'-','LineWidth',2,'color',[121 162 206]./255); 
legend('Dilute channel','Concentrate channel','location','northwest'); legend boxoff
% ylabel('$m_e$   /   mol kg$^{-1}$','Interpreter','latex')
ylabel('$T$   /   K','Interpreter','latex')
xlabel('$z$ L$^{-1}$   /   $-$','Interpreter','latex')
ylim([313 314])
% yticklabels({'0.1','1','2'});
% yticks([0.1 1 2])
set(gca,'FontName','Arial','FontSize',18,'linewidth',1.2);
set(gcf,'Position', [0 0 800 720]);

dim = [.2 .5 .3 .3];
str1 = '$v_{c}=0.3$ cm s$^{-1}$';  str1 = [str1 newline '$v_{d}=0.2$ cm s$^{-1}$'];
str2 = '$v_{c}=0.5$ cm s$^{-1}$';  str2 = [str2 newline '$v_{d}=0.4$ cm s$^{-1}$'];
str3 = '$v_{c}=1.2$ cm s$^{-1}$';  str3 = [str3 newline '$v_{d}=1.0$ cm s$^{-1}$'];
annotation('textbox',dim,'String',str1,'FitBoxToText','on','LineStyle','none','FontSize',16,'Interpreter','latex');
annotation('textbox',dim,'String',str2,'FitBoxToText','on','LineStyle','none','FontSize',16,'Interpreter','latex');
annotation('textbox',dim,'String',str3,'FitBoxToText','on','LineStyle','none','FontSize',16,'Interpreter','latex');


%% SAVE
% cd C:\PhD\HeatToH2\Figures\ModelPaper\Graphs
% exportgraphics(gcf,'v_vs_T.png','Resolution',300)
% cd C:\MATLAB\Heat2H2
