function precip = precipRegen(p)
global c

%% Dependence of n1 and n2 on slurry concentration
% ns = 8;
% x=linspace(3,50,100);
% y1=(p.m_c(ns,end)*(p.n_c(ns,end)-p.n_c(ns,1)).*p.N_unit+p.m_c(ns,end).*x.*c.Mw.*(p.n_wc(ns,end)-p.n_wc(ns,1)).*p.N_unit)./(p.m_c(ns,end)-x);
% y2=(p.n_c(ns,end)-p.n_c(ns,1)).*p.N_unit - y1;
% plot(x,y1); hold on
% plot(x,-y2)

%% For counter-current flow
precip.Ns(:,1) = p.n_c(:,end).*p.N_unit; % Concentrate outlet salt flow
precip.Ns(:,2) = p.n_d(:,1).*p.N_unit;   % Dilute      outlet salt flow
% Stream n1, side flow from spent concentrate to spent dilute
precip.Ns(:,3) = -(-p.m_c(:,end).*(p.n_c(:,end)-p.n_c(:,1)).*p.N_unit + p.m_c(:,end).*c.m_slurry.*c.Mw.*(p.n_wc(:,end)-p.n_wc(:,1)).*p.N_unit)./(p.m_c(:,end)-c.m_slurry);
% Stream n2, salt flow from slurry tank to spent concentrate
precip.Ns(:,4) = -(p.n_c(:,end)-p.n_c(:,1)).*p.N_unit + precip.Ns(:,3); 
precip.Ns(:,5) = precip.Ns(:,1)-precip.Ns(:,3)+precip.Ns(:,4); % Refreshed concentrate
precip.Ns(:,6) = precip.Ns(:,2)+precip.Ns(:,3)-precip.Ns(:,4); % Refreshed dilute
precip.Ns(:,7) = p.n_c(:,1).*p.N_unit;      % Concentrate inlet salt flow
precip.Ns(:,8) = p.n_d(:,end).*p.N_unit;    % Dilute      inlet salt flow

precip.Nw(:,1) = p.n_wc(:,end).*p.N_unit; % Concentrate outlet salt flow
precip.Nw(:,2) = p.n_wd(:,1).*p.N_unit;   % Dilute      outlet salt flow
% Stream n1, side flow from spent concentrate to spent dilute
precip.Nw(:,3) = precip.Ns(:,3)./p.m_c(:,end)./c.Mw;
% Stream n2, water flow from slurry tank to spent concentrate
precip.Nw(:,4) = precip.Ns(:,4)./c.m_slurry./c.Mw;
precip.Nw(:,5) = precip.Nw(:,1)-precip.Nw(:,3)+precip.Nw(:,4); % Refreshed concentrate
precip.Nw(:,6) = precip.Nw(:,2)+precip.Nw(:,3)-precip.Nw(:,4); % Refreshed dilute
precip.Nw(:,7) = p.n_wc(:,1).*p.N_unit;     % Concentrate inlet salt flow
precip.Nw(:,8) = p.n_wd(:,end).*p.N_unit;   % Dilute      inlet salt flow

precip.Ftot(:,1) = precip.Ns(:,1).*c.Mi + precip.Nw(:,1).*c.Mw; % Total mass flow out of concentrate
precip.Ftot(:,2) = precip.Ns(:,2).*c.Mi + precip.Nw(:,2).*c.Mw; % Total mass flow out of dilute
precip.Ftot(:,3) = precip.Ns(:,3).*c.Mi + precip.Nw(:,3).*c.Mw; % Total mass flow side flow
precip.Ftot(:,4) = precip.Ns(:,4).*c.Mi + precip.Nw(:,4).*c.Mw; % Total mass flow out of slurry
precip.Ftot(:,5) = precip.Ns(:,5).*c.Mi + precip.Nw(:,5).*c.Mw; % Total mass flow refreshed conc
precip.Ftot(:,6) = precip.Ns(:,6).*c.Mi + precip.Nw(:,6).*c.Mw; % Total mass flow refreshed dilute
precip.Ftot(:,7) = precip.Ns(:,7).*c.Mi + precip.Nw(:,7).*c.Mw; % Total mass flow INTO concentrate
precip.Ftot(:,8) = precip.Ns(:,8).*c.Mi + precip.Nw(:,8).*c.Mw; % Total mass flow INTO dilute

%% Energy
for i = 1:8
    precip.m(:,i) = precip.Ns(:,i)./(precip.Nw(:,i).*c.Mw);
    precip.m(:,4) = c.S10;
    for n = 1:length(c.Mi)
    [temp1, temp2] = CALC_Hbar(precip.m(n,i), c.T);
    precip.hs(n,i) = temp1(n,1);
    precip.hw(n,i) = temp2(n,1);

    Hmix = CALC_Hmix(precip.m(n,i), c.T);   
    precip.xs(n,i) = precip.m(n,i)./(precip.m(n,i)+1/c.Mw); 
    precip.M(n,i) = (precip.xs(n,i).*c.Mi(n)+(1-precip.xs(n,i)).*c.Mw);
    Hmixn(n,i) = Hmix(n,1).*precip.m(n,i);   % J 
    precip.H(n,i)  = (c.H0f(n)*precip.m(n,i) + c.H0fw/c.Mw + Hmixn(n,i))./(precip.m(n,i)+1/c.Mw)./precip.M(n,i); % J/kg
    
    temp1 = CALC_Cp(precip.m(n,i), c.T)./precip.M(n,i); % J/K kg mixture
    precip.Cp(n,i) = temp1(n,1);
    precip.FH(n,i) = precip.Ftot(n,i).*precip.H(n,i);
    end
end
precip.m2  = (precip.Ns(:,2) + precip.Ns(:,3))./((precip.Nw(:,2)+precip.Nw(:,3)).*c.Mw);
precip.xs2 = precip.m2./(precip.m2+1/c.Mw); 
precip.M2  = (precip.xs2.*c.Mi+(1-precip.xs2).*c.Mw);
precip.Cp2 = CALC_Cp(precip.m2, c.T)./precip.M2; % J/K kg mixture

precip.Q(:,1) = (precip.Ftot(:,2) + precip.Ftot(:,3)).*precip.Cp2.*(c.Tl-p.T_d(:,1)); % Cooling to 10C
precip.Q(:,2) = precip.Ftot(:,6).*precip.Cp(n,4).*(c.T-c.Tl);                       % Heating refreshed dilute to 40C
precip.Q(:,3) = (precip.m2-c.S10).*precip.Nw(:,4).*c.Mw.*(-Hmixn(:,4)./(precip.m(:,4)+1/c.Mw));  % Precipitating 
precip.Q(:,4) = (precip.m(:,7)-c.S10).*precip.Nw(:,4).*c.Mw.*Hmixn(:,4)./(precip.m(:,4)+1/c.Mw); % Dissolving precipitate in this portion
precip.Q(:,5) = precip.Ftot(:,4).*precip.Cp(n,4).*(c.T-c.Tl);                       % Heating portion of slurry to 40C 

end